dnl -*- Mode: m4; tab-width: 2; indent-tabs-mode: nil; -*-
dnl Copyright (C) 2003 Justin Kirby <justin@openaether.org>
dnl  
dnl This file is free software; as a special exception the author gives
dnl unlimited permission to copy and/or distribute it, with or without 
dnl modifications, as long as this notice is preserved.
dnl 
dnl This program is distributed in the hope that it will be useful, but
dnl WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
dnl implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

dnl OAPR_APR_CHECK()
dnl
dnl Search for a useable version of the apr library in a number
dnl of common places
dnl

AC_DEFUN(OAPR_APR_CHECK,
[
  dnl  Process the `with-apr` switch. 
  AC_ARG_WITH(apr,
    AC_HELP_STRING(--with-apr=PATH, [alternate location of apr-config ]),
  [
    if test "$withval" = "yes"; then
      places="search"
      dcheck="$dcheck --with-apr "
    else
      places="$withval"
      dcheck="$dcheck --with-apr=$withval "
    fi
  ],
  [
    places="search"
  ])

  dnl Check and set the places
  
  aprcfg=
  if test "$places" = "search"; then
    aprcfg=$(which apr-config)
    if test -z "$aprcfg"; then
      AC_MSG_ERROR([ apr-config is not in path, specify location with --with-apr])
    fi
  else
    aprcfg="$places/apr-config"
  fi
  AC_MSG_CHECKING([checking for apr-config])
  if test -e "$aprcfg"; then
    AC_MSG_RESULT([yes])
  else
    AC_MSG_ERROR([ $aprcfg does not exist ])
  fi
  apr_cflags=`$aprcfg --cflags`
  apr_cppflags=`$aprcfg --cppflags`
  apr_includes=`$aprcfg --includes`
  apr_ldflags=`$aprcfg --ldflags`
  apr_ldlink=`$aprcfg --link-ld`
  apr_libs=`$aprcfg --libs`
  apr_libtool=`$aprcfg --link-libtool`

  AC_SUBST(apr_cflags)
  AC_SUBST(apr_cppflags)
  AC_SUBST(apr_includes)
  AC_SUBST(apr_ldflags)
  AC_SUBST(apr_ldlink)
  AC_SUBST(apr_libs)
  AC_SUBST(apr_libtool)

])

AC_DEFUN(OAPR_APR_TRY,
  [
    AC_MSG_CHECKING([ for apr lib])
    oapr_save_libs="$LIBS"
    oapr_save_inc="$INCLUDES"
    LIBS="$LIBS $apr_ldlink $apr_libs -lpthread"
    CPPFLAGS="$CPPFLAGS $apr_includes "
    INCLUDES="$INCLUDES $apr_cflags $apr_cppflags $apr_includes "
    AC_TRY_LINK(
      [
        #include "apr_general.h"
      ],
      [
        apr_initialize();
      ],
      [
        oapr_have_apr=yes
        AC_MSG_RESULT([yes])
      ],
      [
        oapr_have_apr=no
        AC_MSG_ERROR([Failed to link with apr])
      ]
    )
    LIBS="$oapr_save_libs"
    INCLUDES="$oapr_save_inc"
  ]
)

