dnl -*- Mode: m4; tab-width: 2; indent-tabs-mode: nil; -*-
dnl Copyright (C) 2003 Justin Kirby <justin@openaether.org>
dnl  
dnl This file is free software; as a special exception the author gives
dnl unlimited permission to copy and/or distribute it, with or without 
dnl modifications, as long as this notice is preserved.
dnl 
dnl This program is distributed in the hope that it will be useful, but
dnl WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
dnl implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

dnl OAPR_APU_CHECK()
dnl
dnl Search for a useable version of the apu library in a number
dnl of common places
dnl

AC_DEFUN(OAPR_APU_CHECK,
[
  dnl  Process the `with-apu` switch. 
  AC_ARG_WITH(apu,
    AC_HELP_STRING(--with-apu=PATH, [alternate location of apu-config ]),
  [
    if test "$withval" = "yes"; then
      apu_places="search"
      dcheck="$dcheck --with-apu "
    else
      apu_places="$withval"
      dcheck="$dcheck --with-apu=$withval "
    fi
  ],
  [
    apu_places="no"
  ])

  dnl Check and set the places

  apucfg=
  AC_MSG_CHECKING([checking for apu-config])  
  if test "$apu_places" = "no"; then
    AM_CONDITIONAL(USE_APU, true)
    AC_MSG_RESULT([no])
  else
    if test "$apu_places" = "search"; then
      apucfg=$(which apu-config)
      if test -z "$apucfg"; then
        AC_MSG_ERROR([ apu-config is not in path, specify location with --with-apu])
      fi
    else
      apucfg="$apu_places/apu-config"
    fi

    if test -e "$apucfg"; then
      AC_MSG_RESULT([yes])
    else
      AC_MSG_ERROR([ $apucfg does not exist ])
    fi
dnl    apu_cflags=$($apucfg --cflags)
dnl    apu_cppflags=`$apucfg --cppflags`
    apu_includes=`$apucfg --includes`
    apu_ldflags=`$apucfg --ldflags`
    apu_ldlink=`$apucfg --link-ld`
    apu_libs=`$apucfg --libs`
    apu_libtool=`$apucfg --link-libtool`

dnl    AC_SUBST(apu_cflags)
dnl    AC_SUBST(apu_cppflags)
    AC_SUBST(apu_includes)
    AC_SUBST(apu_ldflags)
    AC_SUBST(apu_ldlink)
    AC_SUBST(apu_libs)
    AC_SUBST(apu_libtool)
    AM_CONDITIONAL(USE_APU, true)
  fi
])

AC_DEFUN(OAPR_APU_TRY,
  [
    AC_MSG_CHECKING([ for apr-util lib])
    oapu_save_libs="$LIBS"
    oapu_save_inc="$INCLUDES"
    LIBS="$LIBS $apr_ldlink $apr_libs $apu_ldlink $apu_libs "
    CPPFLAGS="$CPPFLAGS $apu_includes $apr_includes "
    AC_TRY_LINK(
      [
        #include "apu_version.h"
      ],
      [
        apu_version_string();
      ],
      [
        oapr_have_apu=yes
        AC_MSG_RESULT([yes])
      ],
      [
        oapr_have_apu=no
        AC_MSG_ERROR([Failed to link with apr-util])
      ]
    )
    LIBS="$oapu_save_libs"
    INCLUDES="$oapu_save_inc"
  ]
)
